pub struct Body(/* private fields */);Expand description
The body type used in axum requests and responses.
Implementations
Sourceimpl Body
impl Body
Sourcepub fn new<B>(body: B) -> Body
pub fn new<B>(body: B) -> Body
Create a new Body that wraps another http_body::Body.
Sourcepub fn from_stream<S>(stream: S) -> Body
pub fn from_stream<S>(stream: S) -> Body
Create a new Body from a Stream.
Sourcepub fn into_data_stream(self) -> BodyDataStream
pub fn into_data_stream(self) -> BodyDataStream
Convert the body into a Stream of data frames.
Non-data frames (such as trailers) will be discarded. Use http_body_util::BodyStream if
you need a Stream of all frame types.