Struct MapResponseLayer
struct MapResponseLayer<F, S, T> { ... }
A tower::Layer from an async function that transforms a response.
Created with map_response. See that function for more details.
Implementations
impl<F, S, T> Clone for MapResponseLayer<F, S, T>
fn clone(self: &Self) -> Self
impl<F, S, T> Debug for MapResponseLayer<F, S, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<F, S, T> Freeze for MapResponseLayer<F, S, T>
impl<F, S, T> RefUnwindSafe for MapResponseLayer<F, S, T>
impl<F, S, T> Send for MapResponseLayer<F, S, T>
impl<F, S, T> Sync for MapResponseLayer<F, S, T>
impl<F, S, T> Unpin for MapResponseLayer<F, S, T>
impl<F, S, T> UnsafeUnpin for MapResponseLayer<F, S, T>
impl<F, S, T> UnwindSafe for MapResponseLayer<F, S, T>
impl<S, I, F, T> Layer for MapResponseLayer<F, S, T>
fn layer(self: &Self, inner: I) -> <Self as >::Service
impl<T> Any for MapResponseLayer<F, S, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for MapResponseLayer<F, S, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for MapResponseLayer<F, S, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for MapResponseLayer<F, S, T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for MapResponseLayer<F, S, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> FromRef for MapResponseLayer<F, S, T>
fn from_ref(input: &T) -> T
impl<T> Instrument for MapResponseLayer<F, S, T>
impl<T> Same for MapResponseLayer<F, S, T>
impl<T> ToOwned for MapResponseLayer<F, S, T>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> WithSubscriber for MapResponseLayer<F, S, T>
impl<T, U> Into for MapResponseLayer<F, S, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for MapResponseLayer<F, S, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for MapResponseLayer<F, S, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<V, T> VZip for MapResponseLayer<F, S, T>
fn vzip(self: Self) -> V