Struct Next

struct Next { ... }

The remainder of a middleware stack, including the handler.

Implementations

impl Next

async fn run(self: Self, req: Request) -> Response

Execute the remaining middleware stack.

impl Clone for Next

fn clone(self: &Self) -> Next

impl Debug for Next

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Next

impl RefUnwindSafe for Next

impl Send for Next

impl Service for Next

fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn call(self: &mut Self, req: Request) -> <Self as >::Future

impl Sync for Next

impl Unpin for Next

impl UnsafeUnpin for Next

impl UnwindSafe for Next

impl<S, R> ServiceExt for Next

fn into_make_service(self: Self) -> IntoMakeService<S>
fn into_make_service_with_connect_info<C>(self: Self) -> IntoMakeServiceWithConnectInfo<S, C>

impl<T> Any for Next

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Next

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Next

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Next

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Next

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> FromRef for Next

fn from_ref(input: &T) -> T

impl<T> Instrument for Next

impl<T> Same for Next

impl<T> ToOwned for Next

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for Next

impl<T, Request> ServiceExt for Next

impl<T, U> Into for Next

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Next

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Next

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<V, T> VZip for Next

fn vzip(self: Self) -> V