EventDataWriter

Struct EventDataWriter 

pub struct EventDataWriter { /* private fields */ }
Expose Event as a std::fmt::Write such that any form of data can be written as data safely.

This also ensures that newline characters \r and \n correctly trigger a split with a new data: prefix.

Panics

Panics if any data has already been written prior to the first write of this EventDataWriter instance.

Implementations

Source

impl EventDataWriter

pub fn into_event(self) -> Event

Consume the EventDataWriter and return the Event once again.

In case any data was written by this instance it will also write the trailing \n character.