TestResponse

Struct TestResponse 

pub struct TestResponse { /* private fields */ }
Available on crate features __private only.

Implementations

Source

impl TestResponse

pub async fn bytes(self) -> Bytes

pub async fn text(self) -> String

pub async fn json<T>(self) -> T

pub async fn chunk(&mut self) -> Option<Bytes>

pub async fn chunk_text(&mut self) -> Option<String>

Methods from Deref<Target = Response>

pub fn status(&self) -> StatusCode

Get the StatusCode of this Response.

pub fn version(&self) -> Version

Get the HTTP Version of this Response.

pub fn headers(&self) -> &HeaderMap

Get the Headers of this Response.

pub fn content_length(&self) -> Option<u64>

Get the content length of the response, if it is known.

This value does not directly represents the value of the Content-Length header, but rather the size of the response’s body. To read the header’s value, please use the Response::headers method instead.

Reasons it may not be known:

  • The response does not include a body (e.g. it responds to a HEAD request).
  • The response is gzipped and automatically decoded (thus changing the actual decoded length).
pub fn url(&self) -> &Url

Get the final Url of this Response.

pub fn remote_addr(&self) -> Option<SocketAddr>

Get the remote address used to get this Response.

pub fn extensions(&self) -> &Extensions

Returns a reference to the associated extensions.

pub fn error_for_status_ref(&self) -> Result<&Response, Error>

Turn a reference to a response into an error if the server returned an error.

Example
fn on_response(res: &Response) {
    match res.error_for_status_ref() {
        Ok(_res) => (),
        Err(err) => {
            // asserting a 400 as an example
            // it could be any status between 400...599
            assert_eq!(
                err.status(),
                Some(reqwest::StatusCode::BAD_REQUEST)
            );
        }
    }
}