Struct RawQuery
struct RawQuery(2330)
Extractor that extracts the raw query string, without parsing it.
Example
use ;
use StreamExt;
async
let app = new.route;
# let _: Router = app;
Implementations
impl Debug for RawQuery
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for RawQuery
impl RefUnwindSafe for RawQuery
impl Send for RawQuery
impl Sync for RawQuery
impl Unpin for RawQuery
impl UnsafeUnpin for RawQuery
impl UnwindSafe for RawQuery
impl<S> FromRequestParts for RawQuery
async fn from_request_parts(parts: &mut Parts, _state: &S) -> Result<Self, <Self as >::Rejection>
impl<S, T> FromRequest for RawQuery
fn from_request(req: Request<Body>, state: &S) -> impl Future<Output = Result<T, <T as FromRequest<S, ViaParts>>::Rejection>>
impl<T> Any for RawQuery
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RawQuery
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RawQuery
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for RawQuery
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Instrument for RawQuery
impl<T> Same for RawQuery
impl<T> WithSubscriber for RawQuery
impl<T, U> Into for RawQuery
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RawQuery
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RawQuery
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<V, T> VZip for RawQuery
fn vzip(self: Self) -> V