Struct MapResponse
struct MapResponse<F, S, I, T> { ... }
A middleware created from an async function that transforms a response.
Created with map_response. See that function for more details.
Implementations
impl<F, Fut, S, I, B, ResBody> Service for MapResponse<F, S, I, ()>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1> Service for MapResponse<F, S, I, (T1)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2> Service for MapResponse<F, S, I, (T1, T2)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3> Service for MapResponse<F, S, I, (T1, T2, T3)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4> Service for MapResponse<F, S, I, (T1, T2, T3, T4)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4, T5> Service for MapResponse<F, S, I, (T1, T2, T3, T4, T5)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4, T5, T6> Service for MapResponse<F, S, I, (T1, T2, T3, T4, T5, T6)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4, T5, T6, T7> Service for MapResponse<F, S, I, (T1, T2, T3, T4, T5, T6, T7)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4, T5, T6, T7, T8> Service for MapResponse<F, S, I, (T1, T2, T3, T4, T5, T6, T7, T8)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4, T5, T6, T7, T8, T9> Service for MapResponse<F, S, I, (T1, T2, T3, T4, T5, T6, T7, T8, T9)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Service for MapResponse<F, S, I, (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Service for MapResponse<F, S, I, (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> Service for MapResponse<F, S, I, (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> Service for MapResponse<F, S, I, (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> Service for MapResponse<F, S, I, (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Service for MapResponse<F, S, I, (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, Fut, S, I, B, ResBody, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16> Service for MapResponse<F, S, I, (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16)>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, req: Request<B>) -> <Self as >::Future
impl<F, S, I, T> Clone for MapResponse<F, S, I, T>
fn clone(self: &Self) -> Self
impl<F, S, I, T> Debug for MapResponse<F, S, I, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<F, S, I, T> Freeze for MapResponse<F, S, I, T>
impl<F, S, I, T> RefUnwindSafe for MapResponse<F, S, I, T>
impl<F, S, I, T> Send for MapResponse<F, S, I, T>
impl<F, S, I, T> Sync for MapResponse<F, S, I, T>
impl<F, S, I, T> Unpin for MapResponse<F, S, I, T>
impl<F, S, I, T> UnsafeUnpin for MapResponse<F, S, I, T>
impl<F, S, I, T> UnwindSafe for MapResponse<F, S, I, T>
impl<M, S, Target, Request> MakeService for MapResponse<F, S, I, T>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <M as MakeService<Target, Request>>::MakeError>>fn make_service(self: &mut Self, target: Target) -> <M as MakeService<Target, Request>>::Future
impl<S, R> ServiceExt for MapResponse<F, S, I, T>
fn into_make_service(self: Self) -> IntoMakeService<S>fn into_make_service_with_connect_info<C>(self: Self) -> IntoMakeServiceWithConnectInfo<S, C>
impl<T> Any for MapResponse<F, S, I, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for MapResponse<F, S, I, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for MapResponse<F, S, I, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for MapResponse<F, S, I, T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for MapResponse<F, S, I, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> FromRef for MapResponse<F, S, I, T>
fn from_ref(input: &T) -> T
impl<T> Instrument for MapResponse<F, S, I, T>
impl<T> Same for MapResponse<F, S, I, T>
impl<T> ToOwned for MapResponse<F, S, I, T>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> WithSubscriber for MapResponse<F, S, I, T>
impl<T, Request> ServiceExt for MapResponse<F, S, I, T>
impl<T, U> Into for MapResponse<F, S, I, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for MapResponse<F, S, I, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for MapResponse<F, S, I, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<V, T> VZip for MapResponse<F, S, I, T>
fn vzip(self: Self) -> V