Trait IntoMapRequestResult

trait IntoMapRequestResult<B>: private::Sealed<B>

Trait implemented by types that can be returned from map_request, map_request_with_state.

This trait is sealed such that it cannot be implemented outside this crate.

Required Methods

fn into_map_request_result(self: Self) -> Result<Request<B>, Response>

Perform the conversion.

Implementors